==> openshift-model-operator-5.7.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/IngressControllerLoggingFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class IngressControllerLoggingFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent<A>{
  public IngressControllerLoggingFluentImpl() {
  }
  public IngressControllerLoggingFluentImpl(io.fabric8.openshift.api.model.operator.v1.IngressControllerLogging instance) {
    this.withAccess(instance.getAccess()); 
  }
  private io.fabric8.openshift.api.model.operator.v1.AccessLoggingBuilder access;
  
  /**
   * This method has been deprecated, please use method buildAccess instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.AccessLogging getAccess() {
    return this.access!=null?this.access.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.AccessLogging buildAccess() {
    return this.access!=null?this.access.build():null;
  }
  public A withAccess(io.fabric8.openshift.api.model.operator.v1.AccessLogging access) {
    _visitables.get("access").remove(this.access);
    if (access!=null){ this.access= new io.fabric8.openshift.api.model.operator.v1.AccessLoggingBuilder(access); _visitables.get("access").add(this.access);} return (A) this;
  }
  public java.lang.Boolean hasAccess() {
    return this.access != null;
  }
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent.AccessNested<A> withNewAccess() {
    return new io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluentImpl.AccessNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent.AccessNested<A> withNewAccessLike(io.fabric8.openshift.api.model.operator.v1.AccessLogging item) {
    return new io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluentImpl.AccessNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent.AccessNested<A> editAccess() {
    return withNewAccessLike(getAccess());
  }
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent.AccessNested<A> editOrNewAccess() {
    return withNewAccessLike(getAccess() != null ? getAccess(): new io.fabric8.openshift.api.model.operator.v1.AccessLoggingBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent.AccessNested<A> editOrNewAccessLike(io.fabric8.openshift.api.model.operator.v1.AccessLogging item) {
    return withNewAccessLike(getAccess() != null ? getAccess(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IngressControllerLoggingFluentImpl that = (IngressControllerLoggingFluentImpl) o;
    if (access != null ? !access.equals(that.access) :that.access != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(access,  super.hashCode());
  }
  public class AccessNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluentImpl<io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent.AccessNested<N>> implements io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent.AccessNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    AccessNestedImpl(io.fabric8.openshift.api.model.operator.v1.AccessLogging item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.AccessLoggingBuilder(this, item);
    }
    AccessNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.AccessLoggingBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.AccessLoggingBuilder builder;
    public N and() {
      return (N) IngressControllerLoggingFluentImpl.this.withAccess(builder.build());
    }
    public N endAccess() {
      return and();
    }
    
  }
  
}

==> openshift-model-operator-5.10.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/IngressControllerLoggingFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class IngressControllerLoggingFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent<A>{
  public IngressControllerLoggingFluentImpl() {
  }
  public IngressControllerLoggingFluentImpl(io.fabric8.openshift.api.model.operator.v1.IngressControllerLogging instance) {
    this.withAccess(instance.getAccess()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.operator.v1.AccessLoggingBuilder access;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildAccess instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.AccessLogging getAccess() {
    return this.access!=null?this.access.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.AccessLogging buildAccess() {
    return this.access!=null?this.access.build():null;
  }
  public A withAccess(io.fabric8.openshift.api.model.operator.v1.AccessLogging access) {
    _visitables.get("access").remove(this.access);
    if (access!=null){ this.access= new io.fabric8.openshift.api.model.operator.v1.AccessLoggingBuilder(access); _visitables.get("access").add(this.access);} return (A) this;
  }
  public java.lang.Boolean hasAccess() {
    return this.access != null;
  }
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent.AccessNested<A> withNewAccess() {
    return new io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluentImpl.AccessNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent.AccessNested<A> withNewAccessLike(io.fabric8.openshift.api.model.operator.v1.AccessLogging item) {
    return new io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluentImpl.AccessNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent.AccessNested<A> editAccess() {
    return withNewAccessLike(getAccess());
  }
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent.AccessNested<A> editOrNewAccess() {
    return withNewAccessLike(getAccess() != null ? getAccess(): new io.fabric8.openshift.api.model.operator.v1.AccessLoggingBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent.AccessNested<A> editOrNewAccessLike(io.fabric8.openshift.api.model.operator.v1.AccessLogging item) {
    return withNewAccessLike(getAccess() != null ? getAccess(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IngressControllerLoggingFluentImpl that = (IngressControllerLoggingFluentImpl) o;
    if (access != null ? !access.equals(that.access) :that.access != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(access,  additionalProperties,  super.hashCode());
  }
  public class AccessNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.AccessLoggingFluentImpl<io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent.AccessNested<N>> implements io.fabric8.openshift.api.model.operator.v1.IngressControllerLoggingFluent.AccessNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    AccessNestedImpl(io.fabric8.openshift.api.model.operator.v1.AccessLogging item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.AccessLoggingBuilder(this, item);
    }
    AccessNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.AccessLoggingBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.AccessLoggingBuilder builder;
    public N and() {
      return (N) IngressControllerLoggingFluentImpl.this.withAccess(builder.build());
    }
    public N endAccess() {
      return and();
    }
    
  }
  
}
